@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-LcdProc
 #
-# This software is Copyright (c) 2014 by Dominique Dumont.
+# This software is Copyright (c) 2016 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -43,7 +43,18 @@ push @fix_warnings,
         name => 'LDCd-0.5.6',
         load_check => 'skip'
     },
-    
+    {
+        name => 'with-2-drivers',
+        check => {
+            'server Hello:0',           qq!"  Bienvenue"! ,
+            'server Hello:1',           qq("   LCDproc et Config::Model!") ,
+            'server Driver', 'curses,lirc',
+            'curses Size', '20x2',
+            'server AutoRotate', 'off',
+            'lirc prog','lcdd',
+        },
+        @fix_warnings ,
+    },
 );
 
 1;
